{% load i18n %}
<select class="custom-select custom-select-sm mb-3" id="metricType" onchange="activateRender()">
    <option selected disabled hidden class="text-gray">-- {% trans "Metric type" %} --</option>
    <option value="page_fan_adds_unique">{% trans "New Fans" %}</option>
    <option value="page_fan_removes_unique">{% trans "Fans Leaves" %}</option>
    <option value="page_fans_country">{% trans "Top Fans Country" %}</option>
    <option value="page_fans_gender_age">{% trans "Top Fans Gender Age" %}</option>
    <option value="page_fans_by_like_source_unique">{% trans "Top Likes Zones" %}</option>
    <option value="page_fans_by_unlike_source_unique">{% trans "Top Unlikes Zones" %}</option>
    <option value="page_engaged_users">{% trans "Engage Users" %}</option>
    <option value="page_consumptions">{% trans "Content Engage" %}</option>
    <option value="page_negative_feedback_unique">{% trans "Negative Feedback" %}</option>
    <option value="page_fan_adds_by_paid_non_paid_unique">{% trans "New Fans by ads" %}</option>
    <option value="page_impressions_unique">{% trans "Page Impressions" %}</option>
    <option value="page_impressions_paid_unique">{% trans "Page Paid Impressions" %}</option>
    <option value="page_impressions_organic_unique_v2">{% trans "Organic Impressions" %}</option>
    <option value="page_impressions_viral_unique">{% trans "Viral Impressions" %}</option>
    <option value="page_impressions_nonviral_unique">{% trans "Nonviral Impressions" %}</option>
    <option value="page_impressions_by_story_type_unique">{% trans "Content Shared Posts" %}</option>
    <option value="page_impressions_by_age_gender_unique">{% trans "Content Age Gender Impressions" %}</option>
</select>