<div class="row">
    <div class="iconCage">
        <div id="iconsuccess"></div>
    </div>
</div>
<div class="row">
    <p>Su registro ha sido procesado de forma exitosa. Hemos enviado un email a su correo {{email}} para la activación de su cuenta.</p>
</div>