{% extends 'dashboard/index.html' %}
<!--Font-Awesome CDN-->
    <link rel="stylesheet" href="https://use.fontawesome.com/releases/v5.15.4/css/all.css" integrity="sha384-DyZ88mC6Up2uqS4h/KRgHuoeGwBcD4Ng9SiP4dIRy0EXTlnuz47vAwmeGwVChigm" crossorigin="anonymous">
    {% block content %}
    <div id="content">
        <section>
          <div class="container">
            <div class="row">
              <div class="col-lg-9">
                <h1 class="font-weight-bold"><i class="icon ed ion-md-analytics"></i> Analytics</h1>
                <P class="text-muted">Revisa la última información</P>
              </div>
            </div>
          </div>
        </section>
    </div>
 </div> 
  </div>
  {% endblock content %}
</html>