{% load crispy_forms_tags %}
{% load i18n %}
{% load hosts %}
<form action="{% host_url 'update_data' host 'stela' %}" method="post" enctype="multipart/form-data" onsubmit="disableBtn()">
    <input type="hidden" name="csrfmiddlewaretoken" id=token4>
  <div class="modal-body mid-modal-scroll modal1">        
      {{form|crispy}}
      <p class="response-footer text-link fw-bold oxanium"></p>
      <input type="hidden" name="obj-id" value={{obj.id}}>
      <input type="hidden" name="form-id" value="categForm">
      <div class="row justify-content-end p-3">
          <div class="col-lg-4">
              <button type="submit" id="btn-footer" name="btn-footer" class="btn btn-shappire center-btn btn-block form-btn d-flex">{% trans "Send " %} <i class="fa-solid fa-paper-plane mx-2"></i></button>      
          </div>
      </div>
  </div>    
</form>