{% load i18n %}
{% load crispy_forms_tags %}
<div class="row">
    <div class="col-lg-12">
        {{form.title|as_crispy_field}}
    </div>
    <div class="col-lg-12">
        {{form.subtitle|as_crispy_field}}
    </div>
    <div class="col-lg-6">
        {{form.status|as_crispy_field}}
    </div>
    <div class="col-lg-6">
        {{form.category|as_crispy_field}}
    </div>
    <div class="col-lg-12">
        <label for="">{% trans "Image or Video" %}</label>
        {{form.media|as_crispy_field}}
    </div>
    <div class="col-lg-12">
        {{form.content|as_crispy_field}}
    </div>
    <div class="col-lg-12">
        <label for="">{% trans "PDF Upload" %}</label>
        {{form.folder_doc|as_crispy_field}}
    </div>
</div>
<input type="hidden" name="form-id" value="blog-form">